==> haskell-blaze-html-0.9.1.2-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-html
version:              0.9.1.2
visibility:           public
id:                   blaze-html-0.9.1.2-EAoJcU0BFWbFaCLDIorxo3
key:                  blaze-html-0.9.1.2-EAoJcU0BFWbFaCLDIorxo3
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  caab57e1d0e382b0952df4b8aa11e5b2
exposed:              True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes

import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-html-0.9.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-html-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-html
hs-libraries:         HSblaze-html-0.9.1.2-EAoJcU0BFWbFaCLDIorxo3
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    blaze-markup-0.8.2.8-1J8XbjxjGC9Hau9a9eQggy bytestring-0.10.12.1
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html:         /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-html-0.9.1.2-203-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-html.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 blaze-html
version:              0.9.1.2
visibility:           public
id:                   blaze-html-0.9.1.2-B48a7xoEadWCpfVMSvtRUE
key:                  blaze-html-0.9.1.2-B48a7xoEadWCpfVMSvtRUE
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast HTML combinator library for Haskell
description:
    A blazingly fast HTML combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  b5ebc149ca0a7376d9c47f45cfec79ba
exposed:              True
exposed-modules:
    Text.Blaze.Html Text.Blaze.Html.Renderer.Pretty
    Text.Blaze.Html.Renderer.String Text.Blaze.Html.Renderer.Text
    Text.Blaze.Html.Renderer.Utf8 Text.Blaze.Html4.FrameSet
    Text.Blaze.Html4.FrameSet.Attributes Text.Blaze.Html4.Strict
    Text.Blaze.Html4.Strict.Attributes Text.Blaze.Html4.Transitional
    Text.Blaze.Html4.Transitional.Attributes Text.Blaze.Html5
    Text.Blaze.Html5.Attributes Text.Blaze.XHtml1.FrameSet
    Text.Blaze.XHtml1.FrameSet.Attributes Text.Blaze.XHtml1.Strict
    Text.Blaze.XHtml1.Strict.Attributes Text.Blaze.XHtml1.Transitional
    Text.Blaze.XHtml1.Transitional.Attributes Text.Blaze.XHtml5
    Text.Blaze.XHtml5.Attributes

import-dirs:          /usr/lib/ghc-9.0.2/site-local/blaze-html-0.9.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/blaze-html-0.9.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-html
hs-libraries:         HSblaze-html-0.9.1.2-B48a7xoEadWCpfVMSvtRUE
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    blaze-markup-0.8.2.8-66mgAiN2tlFEpTLvSDmtm bytestring-0.10.12.1
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-blaze-html/html/blaze-html.haddock
haddock-html:         /usr/share/doc/haskell-blaze-html/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
